<!DOCTYPE TS><TS>
<context>
    <name>String::DayOfWeek</name>
    <message>
        <source>MON</source>
        <translation>LUN</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation>MAR</translation>
    </message>
    <message>
        <source>WED</source>
        <translation>MER</translation>
    </message>
    <message>
        <source>THU</source>
        <translation>GIO</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation>VEN</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation>SAB</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation>DOM</translation>
    </message>
</context>
<context>
    <name>String::WeatherType</name>
    <message>
        <source>Cloudy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mostly Cloudy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Partly Cloudy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Few Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mostly Sunny</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sunny</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scattered Flurries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Isolated T-Storms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scattered Thunderstorms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain/Snow Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Few Snow Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cloudy/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flurries/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mostly Cloudy/Windy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain/Thunder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Partly Cloudy/Windy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Rain/Snow Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Rain/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mostly Sunny/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flurries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sct Flurries/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sct Strong Storms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM T-Storms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thunderstorms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sunny/Windy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Thunderstorms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Iso T-Storms/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain/Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sct T-Storms/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sct Snow Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow to Ice/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow to Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Light Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Light Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain to Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Rain/Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Few Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Rain/Snow Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Rain/Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain/Snow Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain/Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Few Snow Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wintry Mix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Wintry Mix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hvy Rain/Freezing Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Light Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain/Freezing Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>T-Storms/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sprinkles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Snow Showers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Rain/Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rain to Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow to Wintry Mix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Snow Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow and Ice to Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heavy Rain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Rain/Ice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Snow Showers/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Light Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Light Rain/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Light Wintry Mix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Light Snow/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heavy Rain/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Snow Shower</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow to Rain/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Light Rain/Ice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow to Ice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wintry Mix/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Light Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Drizzle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Strong Storms/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PM Drizzle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drizzle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Light Rain/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM Rain/Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wintry Mix to Snow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snow Showers/Windy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Rain Shower</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Rain with Thunder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Drizzle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smoke</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Haze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Snow Shower</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Snow Shower/ Windy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Few Clouds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fair</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>String::WindDirection</name>
    <message>
        <source>N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NNE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ENE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ESE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WSW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WNW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NNW</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>loading...</source>
        <translation>Caricamento...</translation>
    </message>
    <message>
        <source>[ retrieving weather data ... ]</source>
        <translation>[ Recupero dei dati metereologici ... ]</translation>
    </message>
    <message>
        <source>current conditions</source>
        <translation>Condizioni correnti</translation>
    </message>
    <message>
        <source>Humidity</source>
        <translation>Umidità</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Pressione</translation>
    </message>
    <message>
        <source>Wind</source>
        <translation>Vento</translation>
    </message>
    <message>
        <source>Visibility</source>
        <translation>Visibilità</translation>
    </message>
    <message>
        <source>Wind Chill</source>
        <translation>Temperatura</translation>
    </message>
    <message>
        <source>UV Index</source>
        <translation>Indice UV</translation>
    </message>
    <message>
        <source>extended forecast</source>
        <translation>Previsioni del tempo</translation>
    </message>
    <message>
        <source>LO</source>
        <translation>LO</translation>
    </message>
    <message>
        <source>HI</source>
        <translation>HI</translation>
    </message>
    <message>
        <source>today&apos;s forecast</source>
        <translation>Previsioni odierne</translation>
    </message>
    <message>
        <source>tomorrow&apos;s outlook</source>
        <translation>Previsioni per domani</translation>
    </message>
    <message>
        <source>Forecast for</source>
        <translation>Previsioni di</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation>Doppler radar</translation>
    </message>
    <message>
        <source>Map Unavailable</source>
        <translation>Mappa non disponibile</translation>
    </message>
    <message>
        <source>RAIN</source>
        <translation>Pioggia</translation>
    </message>
    <message>
        <source>MIX/ICE</source>
        <translation>Ghiaccio</translation>
    </message>
    <message>
        <source>SNOW</source>
        <translation>Neve</translation>
    </message>
    <message>
        <source>LIGHT</source>
        <translation>Light</translation>
    </message>
    <message>
        <source>HEAVY</source>
        <translation>Heavy</translation>
    </message>
    <message>
        <source>Enter Zip Code</source>
        <translation>Inserisci il codice ZIP</translation>
    </message>
    <message>
        <source>weather setup</source>
        <translation>Impostazioni metereologiche</translation>
    </message>
    <message>
        <source>To save, press &apos;i&apos; - to cancel, hit escape</source>
        <translation>Per salvare, premi &apos;I&apos; - per cancellare, escape</translation>
    </message>
    <message>
        <source>COLD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COLDEST</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CLOUD TEMPERATURE</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Weather</name>
    <message>
        <source> is invalid)</source>
        <translation>non valido)</translation>
    </message>
    <message>
        <source>   No Location Set, Please read the README</source>
        <translation>Nessuna città definita.</translation>
    </message>
    <message>
        <source>Configuring MythWeather...</source>
        <translation>Configurazione di MythWeather</translation>
    </message>
    <message>
        <source>Use the right arrow key to select unit conversion...</source>
        <translation>Usa la freccia destra per selezionare l&apos;unità di misura...</translation>
    </message>
    <message>
        <source>Weather Units</source>
        <translation>Unità di misura</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <source>Aggressiveness</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Configuration Saved...</source>
        <translation>Configurazione memorizzata...</translation>
    </message>
    <message>
        <source>Retrieving weather data...</source>
        <translation>Recupero dei dati metereologici...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select your location...</source>
        <translation>Usa la freccia a destra per selezionare la tua posizione...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select the aggressiveness level...</source>
        <translation>Usa la freccia destra per selezionare la velocità di accesso...</translation>
    </message>
    <message>
        <source> 1  High Speed Connection</source>
        <translation> 1  Connessione ad alta velocità</translation>
    </message>
    <message>
        <source> 8  Medium Speed Connection</source>
        <translation> 8  Connessione a media velocità</translation>
    </message>
    <message>
        <source> 15 Low Speed Connection</source>
        <translation> 15 Connessione a bassa velocità</translation>
    </message>
    <message>
        <source>Obtaining initial weather data...</source>
        <translation>Recupero dei dati metereologici iniziali...</translation>
    </message>
    <message>
        <source>Updating weather data...</source>
        <translation>Aggiornamento dei dati metereologici...</translation>
    </message>
    <message>
        <source>Calm</source>
        <translation>Calma</translation>
    </message>
    <message>
        <source> at </source>
        <translation> a </translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>Illimitata</translation>
    </message>
    <message>
        <source> (minimal)</source>
        <translation> (minimi)</translation>
    </message>
    <message>
        <source> (moderate)</source>
        <translation> (moderati)</translation>
    </message>
    <message>
        <source> (high)</source>
        <translation> (alti)</translation>
    </message>
    <message>
        <source> (extreme)</source>
        <translation> (estremi)</translation>
    </message>
    <message>
        <source>Today a high of </source>
        <translation>Oggi la temperatura massima sarà di </translation>
    </message>
    <message>
        <source> and a low of </source>
        <translation> e la minima di </translation>
    </message>
    <message>
        <source>. Currently there is a humidity of </source>
        <translation>. L&apos;umidità sarà pari al </translation>
    </message>
    <message>
        <source>% and the winds are</source>
        <translation>% ed i venti </translation>
    </message>
    <message>
        <source> calm.</source>
        <translation> saranno calmi.</translation>
    </message>
    <message>
        <source> coming in at </source>
        <translation> spireranno a </translation>
    </message>
    <message>
        <source> mph from the </source>
        <translation> miglia provenienti da </translation>
    </message>
    <message>
        <source> Km/h from the </source>
        <translation> Km/h provenienti da </translation>
    </message>
    <message>
        <source> Visibility will be unlimited for today.</source>
        <translation> Nessun limite alla visibilità.</translation>
    </message>
    <message>
        <source> Visibility conditions are unknown.</source>
        <translation>Non ci sono dati riguardanti la visibilità.</translation>
    </message>
    <message>
        <source> There will be a visibility of </source>
        <translation> La visibilità sarà pari a </translation>
    </message>
    <message>
        <source> miles.</source>
        <translation> miglia.</translation>
    </message>
    <message>
        <source> km.</source>
        <translation> km.</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation type="obsolete">DOM</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domenica</translation>
    </message>
    <message>
        <source>MON</source>
        <translation type="obsolete">LUN</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Lunedì</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation type="obsolete">MAR</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martedì</translation>
    </message>
    <message>
        <source>WED</source>
        <translation type="obsolete">MER</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mercoledì</translation>
    </message>
    <message>
        <source>THU</source>
        <translation type="obsolete">GIO</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Giovedì</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation type="obsolete">VEN</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Venerdì</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation type="obsolete">SAB</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sabato</translation>
    </message>
    <message>
        <source>Date Error</source>
        <translation>Errore nella data</translation>
    </message>
    <message>
        <source>Tomorrow expect a high of </source>
        <translation>La massima di domani sarà di </translation>
    </message>
    <message>
        <source>Expected conditions: </source>
        <translation>Condizioni previste: </translation>
    </message>
    <message>
        <source>Weather data from: </source>
        <translation>Dati metereologici del: </translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Aggiornamento...</translation>
    </message>
    <message>
        <source> (Not All Information Available)</source>
        <translation> (Non tutte le informazioni sono disponibili)</translation>
    </message>
    <message>
        <source>*** Invalid Area ID Entered *** Use a valid area id.</source>
        <translation type="obsolete">*** Area ID invalida *** Usa una valida Area ID.</translation>
    </message>
    <message>
        <source>Weather Data Not Available</source>
        <translation type="obsolete">Dati metereologici non disponibili</translation>
    </message>
    <message>
        <source>!!! Timeout Limit !!! Change aggressiveness level.</source>
        <translation type="obsolete">!!! Tempo esaurito !!! Cambia la tipologia di accesso ad Internet.</translation>
    </message>
    <message>
        <source>*** Invalid Area ID or Server Error ***</source>
        <translation>*** Codice Area non valida oppure Errore Server ***</translation>
    </message>
    <message>
        <source> - PAUSED -</source>
        <translation>- PAUSA -</translation>
    </message>
    <message>
        <source>Imperial (Fahrenheit, in, etc)</source>
        <translation>Anglosassoni (Fahrenheit, in, etc)</translation>
    </message>
    <message>
        <source>Metric (Celsius, kPa, etc)</source>
        <translation>Metriche (Celsius, kPa, etc)</translation>
    </message>
    <message>
        <source> F</source>
        <translation>F</translation>
    </message>
    <message>
        <source> C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation type="unfinished">Doppler radar</translation>
    </message>
    <message>
        <source>satellite image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
